[bitbake-devel] [PATCH 02/14] toaster: base Only show New Build button when there are > 0 projects

Alex DAMIAN alexandru.damian at intel.com
Thu Nov 27 17:07:53 UTC 2014


From: Michael Wood <michael.g.wood at intel.com>

Only show new build button if we have defined at least one project as we
can't select a project to build against if there are no projects created
yet.

Signed-off-by: Michael Wood <michael.g.wood at intel.com>
---
 lib/toaster/toastergui/static/js/base.js   | 13 +++++++++----
 lib/toaster/toastergui/templates/base.html |  1 +
 2 files changed, 10 insertions(+), 4 deletions(-)

diff --git a/lib/toaster/toastergui/templates/base.html b/lib/toaster/toastergui/templates/base.html
index 734d2ad..f457b91 100644
--- a/lib/toaster/toastergui/templates/base.html
+++ b/lib/toaster/toastergui/templates/base.html
@@ -31,6 +31,7 @@
     ctx.projectBuildUrl = "{% url 'xhr_build' %}";
     ctx.projectPageUrl = "{% url 'project' %}";
     ctx.projectInfoUrl = "{% url 'xhr_projectinfo' %}";
+    ctx.numProjects = {{projects|length}};
     {% if project %}
       ctx.projectId = {{project.id}};
     {% endif %}
diff --git a/lib/toaster/toastergui/static/js/base.js b/lib/toaster/toastergui/static/js/base.js
index 864130d..fac59e6 100644
--- a/lib/toaster/toastergui/static/js/base.js
+++ b/lib/toaster/toastergui/static/js/base.js
@@ -3,10 +3,12 @@
 function basePageInit (ctx) {
 
   var newBuildButton = $("#new-build-button");
-  /* Hide the button if we're on the project,newproject or importlyaer page */
-  if (ctx.currentUrl.search('newproject|project/\\d/$|importlayer/$') > 0){
-    newBuildButton.hide();
-    return;
+  /* Hide the button if we're on the project,newproject or importlyaer page
+   * or if there are no projects yet defined
+   */
+  if (ctx.numProjects == 0 || ctx.currentUrl.search('newproject|project/\\d/$|importlayer/$') > 0){
+      newBuildButton.hide();
+      return;
   }
 
 
@@ -17,6 +19,9 @@ function basePageInit (ctx) {
 
 
   function _checkProjectBuildable(){
+    if (ctx.projectId == undefined)
+      return;
+
     libtoaster.getProjectInfo(ctx.projectInfoUrl, ctx.projectId,
       function(data){
         if (data.machine.name == undefined || data.layers.length == 0) {
-- 
1.9.1




More information about the bitbake-devel mailing list